@@ -10,8 +10,8 @@ URL = "https://meet.jit.si"
 warnings.filterwarnings("ignore", category=UserWarning)
 
 
-def run(room, y4m, lifetime=360):
-    browser = get_chrome_browser(y4m=y4m)
+def run(room, y4m, lifetime=360, headless=1, **kwargs):
+    browser = get_chrome_browser(y4m=y4m, headless=headless)
     browser.get(f'{URL}/{room}')
     # Deprecation Warning
     browser.find_element_by_class_name('action-btn').click()
